Index: content/child/browser_font_resource_trusted.cc |
diff --git a/content/child/browser_font_resource_trusted.cc b/content/child/browser_font_resource_trusted.cc |
index 9c9480b51a3e835cdefbdde7d1f67701b77b3859..3ceca36ac591692a0acc55e73c598ac5cd794e01 100644 |
--- a/content/child/browser_font_resource_trusted.cc |
+++ b/content/child/browser_font_resource_trusted.cc |
@@ -341,11 +341,12 @@ PP_Bool BrowserFontResource_Trusted::DrawTextAt( |
return result; |
SkSurfaceProps props(0, kUnknown_SkPixelGeometry); |
- SkCanvas temp_canvas(bm, props); |
+ cc::PaintCanvas temp_canvas(bm, props); |
DrawTextToCanvas(&temp_canvas, *text, position, color, clip); |
} else { |
- DrawTextToCanvas(canvas, *text, position, color, clip); |
+ cc::PaintCanvas temp_canvas(canvas); |
+ DrawTextToCanvas(&temp_canvas, *text, position, color, clip); |
} |
if (needs_unmapping) |
@@ -414,7 +415,7 @@ int32_t BrowserFontResource_Trusted::PixelOffsetForCharacter( |
} |
void BrowserFontResource_Trusted::DrawTextToCanvas( |
- SkCanvas* destination, |
+ cc::PaintCanvas* destination, |
const PP_BrowserFont_Trusted_TextRun& text, |
const PP_Point* position, |
uint32_t color, |
@@ -424,7 +425,7 @@ void BrowserFontResource_Trusted::DrawTextToCanvas( |
static_cast<float>(position->y)); |
WebRect web_clip; |
if (!clip) { |
// Use entire canvas. SkCanvas doesn't have a size on it, so we just use |
// the current clip bounds. |
SkRect skclip = destination->getLocalClipBounds(); |
web_clip = WebRect(skclip.fLeft, skclip.fTop, skclip.fRight - skclip.fLeft, |
@@ -424,7 +425,7 @@ void BrowserFontResource_Trusted::DrawTextToCanvas( |
WebRect web_clip; |
if (!clip) { |
- // Use entire canvas. SkCanvas doesn't have a size on it, so we just use |
+ // Use entire canvas. PaintCanvas doesn't have a size on it, so we just use |
// the current clip bounds. |
SkRect skclip = destination->getLocalClipBounds(); |